@@ -3,7 +3,6 @@
 
 
 echo "Installing Industrial-textile-defect-classifier ..."
-pip3 install edgesoftware
-sudo mkdir Industrial-textile-defect-classifier
-cd Industrial-textile-defect-classifier 
+
+pip3 install --upgrade pip --user && pip3 install edgesoftware --user
 echo 8f4db493-0381-4391-8ec8-2af1b450ad45 | $HOME/.local/bin/edgesoftware install Industrial-textile-defect-classifier 61703650d8ecccee55019b27
